@@ -1,26 +1,33 @@
 package App::DuckPAN::Cmd::Test;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command for running the tests of this library
-$App::DuckPAN::Cmd::Test::VERSION = '0.184';
+$App::DuckPAN::Cmd::Test::VERSION = '0.185';
 use MooX;
 with qw( App::DuckPAN::Cmd );
 
 use MooX::Options protect_argv => 0;
 
+option full => (
+	is          => 'ro',
+	lazy        => 1,
+	short       => 'f',
+	default     => sub { 0 },
+	doc         => 'run full test suite via dzil',
+);
+
 sub run {
-    my ( $self ) = @_;
+	my ( $self ) = @_;
 
-    my $ret = 0;
+	my $ret = 0;
 
-    if (-e 'dist.ini') {
-      $ret = system('dzil test');
-      $self->app->emit_error('Could not begin testing. Is Dist::Zilla installed?') if $ret == -1;
-    } else {
-      $self->app->emit_notice("Could not find dist.ini.");
-      $ret = system('prove -Ilib');
-    }
+	if ($self->full) {
+		$self->app->emit_error("Could not find dist.ini.") unless -e "dist.ini";
+		$self->app->emit_error("Could not begin testing. Is Dist::Zilla installed?") if $ret = system("dzil test");
+	} else {
+		$self->app->emit_error("Tests failed! See output above for details") if $ret = system("prove -Ilib");
+	}
 
-    return $ret;
+	return $ret;
 }
 
 1;
@@ -35,7 +42,7 @@ App::DuckPAN::Cmd::Test - Command for running the tests of this library
 
 =head1 VERSION
 
-version 0.184
+version 0.185
 
 =head1 AUTHOR
 
